﻿<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:vs="http://schemas.microsoft.com/HTMLIntellisense" 
version="1.0">
    <!-- Ausgabe steuern. -->
    <xsl:strip-space elements="*" />
    <xsl:output method="xml" version="1.0" omit-xml-declaration="no" indent="no" encoding="utf-8" />
    <xsl:param name="FriendlyName" />
    <xsl:variable name="TypePrefix">Type-</xsl:variable>
    <xsl:template match="xs:schema">
        <!-- Copyright-Vermerk. -->
        <xsl:comment> Transformation der XHTML-1.0-Schemata von &lt;http://www.w3.org/TR/xhtml1-schema/&gt; in ein für FrontPage 2003 und Visual Studio .NET lesbares Format, © Christoph Schneegans, &lt;mailto:Christoph@Schneegans.de&gt; </xsl:comment>
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:copy />
            </xsl:for-each>
            <!-- Zusätzliche Attribute in <schema/>. -->
            <xsl:attribute name="vs:clientom">ie5_0dom.tlb</xsl:attribute>
            <xsl:attribute name="vs:friendlyname"><xsl:value-of select="$FriendlyName"/></xsl:attribute>
            <xsl:attribute name="vs:iscasesensitive">true</xsl:attribute>
            <xsl:attribute name="vs:htmlflavor">4.0</xsl:attribute>
            <xsl:attribute name="vs:absolutepositioning">true</xsl:attribute>
            <xsl:attribute name="vs:implicitclosure">false</xsl:attribute>
            <xsl:attribute name="vs:ishtmlschema">true</xsl:attribute>
            <xsl:attribute name="vs:requireattributequotes">true</xsl:attribute>
            <xsl:apply-templates />
        </xsl:copy>
    </xsl:template>
    <!-- <group />-Referenzen auflösen. -->
    <xsl:template match="xs:group[@ref]">
        <xsl:variable name="groupName" select="@ref" />
        <xsl:apply-templates select="/xs:schema/xs:group[@name=$groupName]/*"/>
    </xsl:template>
    <!-- <group name="" /> und <complexType name="" /> brauchen wir nicht mehr. -->
    <xsl:template match="xs:group[@name]|xs:complexType[@name]" />
    <!-- <attribute ref="..." /> aus dem XML-Namensraum auflösen. Funktioniert leider nicht, das name-Attribut muß einen NCName-Wert enthalten. -->
    <!--    <xsl:template match="xs:attribute[@ref='xml:lang']">
        <xs:attribute name="xml:lang" type="Type-LanguageCode" />
    </xsl:template>
    <xsl:template match="xs:attribute[@ref='xml:space']">
        <xs:attribute name="xml:space" fixed="preserve">
            <xs:simpleType>
                <xs:restriction base="xs:NCName">
                    <xs:enumeration value="preserve" />
                </xs:restriction>
            </xs:simpleType>
        </xs:attribute>
    </xsl:template>
	<xsl:template match="xs:import[@namespace='http://www.w3.org/XML/1998/namespace']" /> -->
    <!-- "vs:builder"-Attribute anbringen. -->
    <xsl:template match="xs:attribute[@name]">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:call-template name="changeTypeAndBaseAttr" />
            </xsl:for-each>
            <xsl:if test="@type='StyleSheet'">
                <xsl:attribute name="vs:builder">style</xsl:attribute>
            </xsl:if>
            <xsl:if test="@type='URI'">
                <xsl:attribute name="vs:builder">url</xsl:attribute>
            </xsl:if>
            <xsl:if test="@type='Color'">
                <xsl:attribute name="vs:builder">color</xsl:attribute>
            </xsl:if>
            <xsl:apply-templates />
        </xsl:copy>
    </xsl:template>
    <!-- <complexContent /> auflösen. -->
    <xsl:template match="xs:complexContent">
        <xsl:variable name="baseType" select="xs:extension/@base" />
        <xsl:apply-templates select="/xs:schema/xs:complexType[@name=$baseType]/*"/>
        <!-- <attribute /> und <attributeGroup /> kopieren. -->
        <xsl:apply-templates select="xs:extension/*" />
    </xsl:template>
    <xsl:template match="*">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:call-template name="changeTypeAndBaseAttr" />
            </xsl:for-each>
            <xsl:apply-templates />
            <!-- xmlns-"Attribut" erstellen. Dadurch wird dummerweise das Schema ungültig, FrontPage kommt damit aber klar. -->
            <!--
            <xsl:if test="name(.)='xs:complexType' and name(..)='xs:element' and ../@name='html'">
                <xs:attribute name="xmlns" fixed="http://www.w3.org/1999/xhtml">
                    <xs:simpleType>
                        <xs:restriction base="xs:anyURI">
                            <xs:enumeration value="http://www.w3.org/1999/xhtml" />
                        </xs:restriction>
                    </xs:simpleType>
                </xs:attribute>
            </xsl:if>
-->
        </xsl:copy>
    </xsl:template>
    <!-- Wenn Typen und Elemente dieselben Namen haben, kommt FrontPage durcheinander. -->
    <xsl:template match="xs:simpleType">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:call-template name="changeNameAttr" />
            </xsl:for-each>
            <xsl:apply-templates />
        </xsl:copy>
    </xsl:template>
    <!-- type-Attribute müssen das Präfix des Typnamens auch mitkriegen. -->
    <xsl:template name="changeTypeAndBaseAttr">
        <xsl:choose>
            <xsl:when test="name(.)='type' and not(contains(., ':'))">
                <xsl:attribute name="type"><xsl:value-of select="$TypePrefix" /><xsl:value-of select="../@type" /></xsl:attribute>
            </xsl:when>
            <xsl:when test="name(.)='base' and not(contains(., ':'))">
                <xsl:attribute name="base"><xsl:value-of select="$TypePrefix" /><xsl:value-of select="../@base" /></xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:copy />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- name-Attribut bei <simpleType /> ändern. -->
    <xsl:template name="changeNameAttr">
        <xsl:choose>
            <xsl:when test="name(.)='name'">
                <xsl:attribute name="name"><xsl:value-of select="$TypePrefix" /><xsl:value-of select="../@name" /></xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:copy />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Praktische Erweiterungen, die nicht im Original stehen. -->
    <xsl:template match="xs:simpleType[@name='LinkTypes']">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:call-template name="changeNameAttr" />
            </xsl:for-each>
            <xs:union>
                <xs:simpleType>
                    <xs:restriction base="xs:NMTOKENS">
                        <xs:enumeration value="Alternate" />
                        <xs:enumeration value="Appendix" />
                        <xs:enumeration value="Bookmark" />
                        <xs:enumeration value="Chapter" />
                        <xs:enumeration value="Contents" />
                        <xs:enumeration value="Copyright" />
                        <xs:enumeration value="Glossary" />
                        <xs:enumeration value="Help" />
                        <xs:enumeration value="Index" />
                        <xs:enumeration value="Next" />
                        <xs:enumeration value="Offline" />
                        <xs:enumeration value="Prev" />
                        <xs:enumeration value="Section" />
                        <xs:enumeration value="Shortcut Icon" />
                        <xs:enumeration value="Start" />
                        <xs:enumeration value="Stylesheet" />
                        <xs:enumeration value="Subsection" />
                    </xs:restriction>
                </xs:simpleType>
                <xs:simpleType>
                    <xs:restriction base="xs:NMTOKENS" />
                </xs:simpleType>
            </xs:union>
        </xsl:copy>
    </xsl:template>
    <xsl:template match="xs:simpleType[@name='FrameTarget']">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:call-template name="changeNameAttr" />
            </xsl:for-each>
            <xs:union>
                <xs:simpleType>
                    <xs:restriction base="xs:NMTOKEN">
                        <xs:enumeration value="_blank" />
                        <xs:enumeration value="_parent" />
                        <xs:enumeration value="_self" />
                        <xs:enumeration value="_top" />
                    </xs:restriction>
                </xs:simpleType>
                <xs:simpleType>
                    <xs:restriction base="xs:NMTOKEN">
                        <xs:pattern value="[A-Za-z]\c*"/>
                    </xs:restriction>
                </xs:simpleType>
            </xs:union>
        </xsl:copy>
    </xsl:template>
    <xsl:template match="xs:simpleType[@name='ContentType']">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:call-template name="changeNameAttr" />
            </xsl:for-each>
            <xs:union>
                <xs:simpleType>
                    <xs:restriction base="xs:string">
                        <xs:enumeration value="text/css" />
                        <xs:enumeration value="text/javascript" />
                    </xs:restriction>
                </xs:simpleType>
                <xs:simpleType>
                    <xs:restriction base="xs:string" />
                </xs:simpleType>
            </xs:union>
        </xsl:copy>
    </xsl:template>
    <xsl:template match="xs:simpleType[@name='LanguageCode']">
        <xsl:copy>
            <xsl:for-each select="@*">
                <xsl:call-template name="changeNameAttr" />
            </xsl:for-each>
            <xs:union>
                <xs:simpleType>
                    <xs:restriction base="xs:string">
                        <xs:enumeration value="en" />
                        <xs:enumeration value="de" />
                        <xs:enumeration value="de-DE" />
                        <xs:enumeration value="de-AT" />
                        <xs:enumeration value="de-CH" />
                        <xs:enumeration value="fr" />
                    </xs:restriction>
                </xs:simpleType>
                <xs:simpleType>
                    <xs:restriction base="xs:language" />
                </xs:simpleType>
            </xs:union>
        </xsl:copy>
    </xsl:template>
    <!-- Annotationen brauchen wir nicht. -->
    <xsl:template match="xs:annotation" />
    <!-- Verarbeitungsanweisungen und Kommentare sollen nicht kopiert werden. -->
    <xsl:template match="processing-instruction()|comment()" />
</xsl:stylesheet>